Enum Tamptrg
#[repr(u8)]pub enum Tamptrg {
RisingEdge = 0,
FallingEdge = 1,
}Variants
RisingEdge = 0
If TAMPFLT = 00: RTC_TAMPx input rising edge triggers a tamper detection event. If TAMPFLT ≠ 00: RTC_TAMPx input staying low triggers a tamper detection event.
FallingEdge = 1
If TAMPFLT = 00: RTC_TAMPx input staying high triggers a tamper detection event. If TAMPFLT ≠ 00: RTC_TAMPx input falling edge triggers a tamper detection event
Implementations